ColorChannelShift class

Settings to shift color channels.

Constructors

ColorChannelShift({List<Color> colors = const [Colors.red, Colors.green, Colors.blue], Duration delay = const Duration(milliseconds: 100), int spread = 10})
const

Properties

colors → List<Color>
Colors to shift.
final
delay → Duration
Delay between shifts.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spread → int
Spread of the shift.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override